import 'package:flutter/material.dart';
import '../comment_http/httpindex.dart';
import '../page_state.dart';

class CommonBaseConfig {
  static Map<String, CommonErrorModel>? placeholdinfo;

  static Widget? loadWidget;
}

class CommonErrorModel {
  /// 站位图
  Widget? icon;

  /// 站位描述语
  String? desc;

  /// 站位图 本地图片路径
  String? imageAssert;

  /// 站位图大小
  Size? imageSize;

  /// 失败界面 大小
  double? size;

  /// 背景颜色
  Color? backgroundColor;

  /// 按钮与图片的距离
  double? space;

  /// 字体配置
  TextStyle? textStyle;

  /// 按钮
  Widget? buttonWidget;

  /// 扩展字段
  Map? extendInfo;

  /// 描述语
  String? message;

  CommonErrorModel({
    this.icon,
    this.desc,
    this.imageAssert,
    this.imageSize,
    this.backgroundColor,
    this.space,
    this.textStyle,
    this.buttonWidget,
    this.extendInfo,
    this.message,
    this.size,
  });
}

class CommonBasePage extends StatelessWidget {
  // 网络请求状态
  final PageState pageState;
  // 错误信息
  final HttpException? baseError;
  // 按钮点击事件回调 1 刷新网络请求 2 处理其他事件
  final Function(int index)? buttonActionCallback;
  // 子视图
  final Widget? child;
  // 站位图
  final Widget? errorWidget;
  // 站位描述语
  final String? desc;

  /// 描述语
  final String? message;
  // 站位图 本地图片路径
  final String? imageAssert;
  // 站位图大小
  final Size? imageSize;
  // 是否显示加载动画
  final bool? isshowloading;

  final String? placetype;

  const CommonBasePage(
      {Key? key,
      required this.pageState,
      this.baseError,
      this.buttonActionCallback,
      this.child,
      this.errorWidget,
      this.desc,
      this.imageSize,
      this.imageAssert,
      this.placetype,
      this.message,
      this.isshowloading = false})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    if (pageState == PageState.errorState ||
        pageState == PageState.errorshowRelesh ||
        pageState == PageState.emptyDataState) {
      if (errorWidget != null) {
        return errorWidget!;
      } else {
        if (placetype != null) {
          CommonErrorModel? commonErrorModel =
              CommonBaseConfig.placeholdinfo?[placetype!];
          return CommonErrorPage(
            pageState: pageState,
            desc: commonErrorModel?.desc,
            imageAssert: commonErrorModel?.imageAssert,
            imageSize: commonErrorModel?.imageSize,
            icon: commonErrorModel?.icon,
            buttonWidget: commonErrorModel?.buttonWidget,
            backgroundColor: commonErrorModel?.backgroundColor,
            textStyle: commonErrorModel?.textStyle,
            size: commonErrorModel?.size,
            message: commonErrorModel?.message,
          );
        } else if (imageAssert != null) {
          return CommonErrorPage(
              pageState: pageState,
              desc: desc,
              imageAssert: imageAssert,
              imageSize: imageSize);
        }
      }
    } else if (isshowloading! && pageState == PageState.initializedState) {
      return Center(child: CommonBaseConfig.loadWidget ?? Container());
    }
    return child ?? Container();
  }
}

class CommonErrorPage extends StatelessWidget {
  const CommonErrorPage(
      {Key? key,
      required this.pageState,
      this.icon,
      this.desc,
      this.imageAssert,
      this.imageSize,
      this.size,
      this.backgroundColor,
      this.space = 20,
      this.textStyle,
      this.messageStyle,
      this.buttonWidget,
      this.extendInfo,
      this.message,
      this.onTap})
      : super(key: key);

  // 站位图
  final Widget? icon;
  // 站位描述语
  final String? desc;
  // 站位图 本地图片路径
  final String? imageAssert;
  // 站位图大小
  final Size? imageSize;
  // 状态
  final PageState pageState;
  // 背景颜色
  final Color? backgroundColor;
  // 布局大小
  final double? size;
  // 按钮与图片的距离
  final double? space;
  // 字体配置
  final TextStyle? textStyle;
  // message
  final TextStyle? messageStyle;
  // 按钮
  final Widget? buttonWidget;

  /// 描述语
  final String? message;

  final GestureTapCallback? onTap;
  // 扩展字段
  final Map? extendInfo;

  @override
  Widget build(BuildContext context) {
    return Container(
      height: size ?? double.infinity,
      width: size ?? double.infinity,
      padding: const EdgeInsets.only(top: 32, right: 32),
      decoration: BoxDecoration(color: backgroundColor ?? Colors.white),
      child: Column(
        children: [
          createImage(),
          createTitle(),
          createMessage(),
          createBtn(context)
        ],
      ),
    );
  }

  Widget createImage() {
    return icon == null
        ? Container(
            constraints: const BoxConstraints(maxWidth: 200),
            child: Image.asset(
              imageAssert != null
                  ? imageAssert!
                  : configPageStateImageStr(pageState),
              fit: BoxFit.scaleDown,
              width: imageSize == null ? 200 : imageSize!.width,
              height: imageSize == null ? 200 : imageSize!.height,
            ),
          )
        : icon!;
  }

  Widget createTitle() {
    return desc == null
        ? Container()
        : Container(
            margin: EdgeInsets.only(top: space ?? 20, bottom: space ?? 0),
            child: Text(
              desc!,
              style: textStyle,
            ),
          );
  }

  Widget createMessage() {
    return message == null
        ? Container()
        : Container(
            margin: EdgeInsets.only(top: space ?? 20, bottom: space ?? 0),
            child: Text(
              desc!,
              style: textStyle,
            ),
          );
  }

  Widget createBtn(BuildContext context) {
    return Container(
      margin: EdgeInsets.only(top: space ?? 20, bottom: space ?? 20),
      child: buttonWidget ??
          InkWell(
            onTap: () {
              if (onTap != null) {
                onTap!();
              }
            },
            child: Container(
              decoration: BoxDecoration(
                color: Theme.of(context).colorScheme.secondary,
                borderRadius: const BorderRadius.all(
                  Radius.circular(
                    22,
                  ),
                ),
              ),
              height: 44,
              child: Text(
                "点击刷新",
                style: TextStyle(color: Theme.of(context).primaryColor),
              ),
            ),
          ),
    );
  }

  String configPageStateImageStr(PageState state) {
    var imageStr = "";
    switch (state) {
      case PageState.emptyDataState:
        //imageStr = ImageConfig.configImagePath(ImageNameEnum.nothing);
        break;
      default:
    }
    return imageStr;
  }
}
